@@ -41,11 +41,11 @@ def _parse_button_commands(command, user, choice, rand_chars):
         _started_buttons[command][user][rand_chars] = choice
         return render_template(
             "index.html",
-            html="<h1>your request has been processed, you can close this tab</h1>",
+            html="<center><h1>your request has been processed, you can close this tab</h1></center>",
         )
     else:
         return render_template(
-            "index.html", html="<h1>you cannot do this right now</h1>"
+            "index.html", html="<center><h1>you cannot do this right now</h1></center>"
         )
 
 
@@ -125,7 +125,7 @@ class Bot(Client):
         self.listeners = {}
         self.threads_ = []
         self._call_when_followed = lambda ctx, person_who_followed: logging.info(
-            f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} {person_who_followed} followed bot"
+            f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} @{person_who_followed.username} followed bot"
         )
         self._allow_api = allow_api
         self._create_docs = create_docs
@@ -204,8 +204,8 @@ class Bot(Client):
 
         output = {
             "options": {},
-            "ping statement": splited[0],
-            "command": splited[1].lstrip(self.prefix),
+            "ping statement": splited[0].strip(),
+            "command": splited[1].lstrip(self.prefix).strip(),
         }
         _current_command = None
         current = ""
@@ -248,6 +248,7 @@ class Bot(Client):
         return (True, output)
 
     def create_docs(self) -> None:
+        """automatically creates the documentation for the bot"""
         html = ORIGINAL_HTML.format(
             self.user.username,
             self.prefix,
@@ -305,6 +306,7 @@ class Bot(Client):
             return render_template("index.html", html=html)
 
     def _delete_threads(self) -> None:
+        """thread to always destroy threads"""
         while True:
             for i in self.threads_:
                 i.join()
@@ -327,7 +329,15 @@ class Bot(Client):
 
         def _run(notif) -> None:
             """main runner code"""
-            if getattr(notif, "comment", False):
+            # MentionedInPost, MentionedInComment, RepliedToComment, RepliedToPost, AnswerAccepted, MultiplayerJoinedEmail, MultiplayerJoinedLink, MultiplayerInvited, MultiplayerOverlimit, Warning, TeamInvite, TeamOrganizationInvite, Basic, TeamTemplateSubmitted, TeamTemplateReviewedStatus, Annotation, EditRequestCreated, EditRequestAccepted, ReplCommentCreated, ReplCommentReplyCreated, ReplCommentMention, Thread, NewFollower
+            __typename = getattr(notif, "__typename")
+            if __typename == "WarningNotification":
+                logging.critical(
+                    f"{red}[FILE] BOT.py{end}\n{red}[INFO]{end} bot has been warned"
+                )
+            elif __typename == "NewFollowerNotification":
+                self._call_when_followed(self, notif.creator)
+            elif getattr(notif, "comment", False):
                 notif.comment.author = notif.comment.user
                 notif.comment.author.mention = "@" + notif.comment.author.username
                 notif.comment.Image = lambda url, caption="": f"![{caption}]({url})"
@@ -409,7 +419,7 @@ class Bot(Client):
                         notif.comment.reply(__current)
                 elif "command" in parsed_json:
                     logging.info(
-                        f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} logging command\n\t{blue}[SUMMARY]{end} unsucessful: {red}Invalid command{end}.\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
+                        f"{green}[FILE] BOT.py{end}\n{green}[INFO]{end} logging command\n\t{blue}[SUMMARY]{end} unsuccessful: {red}Invalid command{end}.\n\t{purple}[EXTRA]{end} Requested command: {parsed_json['command']}"
                     )
                     __current = "That is not a valid command."
                     __current += (
