@@ -415,6 +415,8 @@ class NotificationManager:
         for n in notifications:
             notification = Notification(self.c)
             notification.update(n)
+            if getattr(notification, "id", None) == None:
+                continue
             if options.cache:
                 self.cache[notification.id] = notification
             c[notification.id] = notification
@@ -1045,17 +1047,6 @@ class Repl:
                     visited[j] = True
         return voters
 
-    # def suggest(self, filePath: str, stopTokens: List[str] = ["\n\n"], tokenNumber: int = 29, lang: str = None, engine: str = "self-hosted-large") -> str:
-    #     _headers = headers
-    #     _headers["Cookie"] = f"connect.sid={self.c.sid}"
-    #     return _raw_post("https://replit.com/suggest_code", json = {
-    #         "language": lang,
-    #         "maxTokens": tokenNumber,
-    #         "stop": stopTokens,
-    #         "filePath": filePath,
-    #         "replId": self.id,
-    #     }, headers = _headers).text.strip().split('\n')
-
 
 class Post:
     def __init__(self, client) -> None:
@@ -1097,6 +1088,7 @@ class Post:
 class Notification:
     def __init__(self, client) -> None:
         self.c = client
+        self.id = None
 
     def update(self, data: Dict[str, Any]):
         notif_data = {"timeCreated": None, "creator": None, "replComment": None}
@@ -1108,7 +1100,7 @@ class Notification:
         if notif_data["timeCreated"]:
             self.timeCreated = notif_data["timeCreated"]
         if notif_data["creator"]:
-            self.creator = self.c.users.fetch(notif_data["creator"])
+            self.creator = self.c.users.fetch(notif_data["creator"]["username"])
         if notif_data["replComment"]:
             self.comment = self.c.comments.fetch(
                 int(notif_data["replComment"]["id"]), **notif_data["replComment"]
